==> haskell-hinotify-0.4-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hinotify
version:              0.4
visibility:           public
id:                   hinotify-0.4-36MohzjuhwbALINiax9M2p
key:                  hinotify-0.4-36MohzjuhwbALINiax9M2p
license:              BSD-3-Clause
maintainer:           Lennart Kolmodin <kolmodin@gmail.com>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify.git
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  3351211e5cc9c873553cafb78cf4f7d3
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-8.8.1/site-local/hinotify-0.4
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hinotify-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hinotify-0.4
hs-libraries:         HShinotify-0.4-36MohzjuhwbALINiax9M2p
includes:             sys/inotify.h
depends:
    async-2.2.2-JbTI50oMvRQ99Orc9hydUg base-4.13.0.0
    bytestring-0.10.9.0 containers-0.6.2.1 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hinotify-0.4-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hinotify
version:              0.4
visibility:           public
id:                   hinotify-0.4-9VMZotn6AKbPQt1cdnqo
key:                  hinotify-0.4-9VMZotn6AKbPQt1cdnqo
license:              BSD-3-Clause
maintainer:           Lennart Kolmodin <kolmodin@gmail.com>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify.git
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  ebfb27fd558f93a7383fe4e7f5d69e7f
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-8.8.2/site-local/hinotify-0.4
library-dirs:         /usr/lib/ghc-8.8.2/site-local/hinotify-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/hinotify-0.4
hs-libraries:         HShinotify-0.4-9VMZotn6AKbPQt1cdnqo
includes:             sys/inotify.h
depends:
    async-2.2.2-26QXzOS0mu2H7YxyeMvEdZ base-4.13.0.0
    bytestring-0.10.10.0 containers-0.6.2.1 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
